@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/proc_if.c
  *
- * Copyright (C) 2005-2010  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.7.2   2010/04/01
+ * Version: 1.7.3   2011/04/01
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -287,7 +287,8 @@ static void __init ccs_proc_init(void)
 #endif
 	ccs_create_entry("self_domain",      0400, ccs_dir, CCS_SELFDOMAIN);
 	ccs_create_entry(".domain_status",   0600, ccs_dir, CCS_DOMAIN_STATUS);
-	ccs_create_entry(".process_status",  0600, ccs_dir, CCS_PROCESS_STATUS);
+	ccs_create_entry(".process_status",  0600, ccs_dir,
+			 CCS_PROCESS_STATUS);
 	ccs_create_entry("meminfo",          0600, ccs_dir, CCS_MEMINFO);
 	ccs_create_entry("profile",          0600, ccs_dir, CCS_PROFILE);
 	ccs_create_entry("manager",          0600, ccs_dir, CCS_MANAGER);
@@ -306,7 +307,7 @@ static int __init ccs_init_module(void)
 {
 	if (ccsecurity_ops.disabled)
 		return -EINVAL;
-#if LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 0)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 0)
 	MOD_INC_USE_COUNT;
 #endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 19)
@@ -321,7 +322,6 @@ static int __init ccs_init_module(void)
 	ccs_signal_init();
 	ccs_mount_init();
 	ccs_maymount_init();
-	ccs_autobind_init();
 	ccs_policy_io_init();
 	ccs_domain_init();
 	return 0;
